{{ fullname | escape | underline }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :special-members: __contains__,__iter__,__len__,__add__,__sub__,__mul__,__div__,__neg__
   :members:
   :exclude-members: __getitem__,__init__
